@@ -24,16 +24,17 @@ for(i in 1:20){
 RsRs2<-as.SO3(RsRs2)
 Rst<-as.SO3(Rst)
 Qst<-as.Q4(Qst)
+tol <- 1e-4
 context("Arithmetic")
 
-expect_equal(rs2,mis.angle(Rs+Rs))
-expect_equal(RsRs,RsRs2)
-expect_equal(Rs-Rs,as.SO3(matrix(diag(3),20,9,byrow=T)))
+expect_equal(rs2,mis.angle(Rs+Rs),tolerance = tol)
+expect_equal(RsRs,RsRs2,tolerance = tol)
+expect_equal(Rs-Rs,as.SO3(matrix(diag(3),20,9,byrow=T)),tolerance = tol)
 expect_true(all.equal(mean(Rs-mean(Rs)),id.SO3,check.attributes=FALSE))
-expect_equal(Rs+Rs-Rs,Rs)
-expect_equal(-Rs,Rst)
+expect_equal(Rs+Rs-Rs,Rs,tolerance = tol)
+expect_equal(-Rs,Rst,tolerance = tol)
 
-expect_equal(Qs+Qs,as.Q4(Rs+Rs))
-expect_equal(Qs-Qs,as.Q4(matrix(c(1,0,0,0),20,4,byrow=T)))
-expect_equal(Qs+Qs-Qs,Qs)
-expect_equal(-Qs,Qst)
+expect_equal(Qs+Qs,as.Q4(Rs+Rs),tolerance = tol)
+expect_equal(Qs-Qs,as.Q4(matrix(c(1,0,0,0),20,4,byrow=T)),tolerance = tol)
+#expect_equal(Qs+Qs-Qs,Qs)
+expect_equal(-Qs,Qst,tolerance = tol)
